@@ -4,22 +4,21 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
+#include <KLocalizedString>
 #include <QCryptographicHash>
 #include <QDateTime>
 #include <QDebug>
 #include <QFile>
 #include <QFileInfo>
-#include <QNetworkAccessManager>
 #include <QNetworkReply>
 #include <QStandardPaths>
 #include <QTextDocumentFragment>
 
-#include <Syndication/Syndication>
-
 #include "database.h"
 #include "fetcher.h"
 
 Fetcher::Fetcher()
+    : m_fetchCount(0)
 {
     manager = new QNetworkAccessManager(this);
     manager->setRedirectPolicy(QNetworkRequest::NoLessSafeRedirectPolicy);
@@ -27,15 +26,17 @@ Fetcher::Fetcher()
     manager->enableStrictTransportSecurityStore(true);
 }
 
-void Fetcher::fetch(const QString &url)
+void Fetcher::fetch(const QString &url, const bool markEntriesRead)
 {
     qDebug() << "Starting to fetch" << url;
 
     Q_EMIT startedFetchingFeed(url);
+    setFetchCount(m_fetchCount + 1);
 
     QNetworkRequest request((QUrl(url)));
     QNetworkReply *reply = get(request);
-    connect(reply, &QNetworkReply::finished, this, [this, url, reply]() {
+    connect(reply, &QNetworkReply::finished, this, [this, url, reply, markEntriesRead]() {
+        setFetchCount(m_fetchCount - 1);
         if (reply->error()) {
             qWarning() << "Error fetching feed";
             qWarning() << reply->errorString();
@@ -44,7 +45,7 @@ void Fetcher::fetch(const QString &url)
             QByteArray data = reply->readAll();
             Syndication::DocumentSource document(data, url);
             Syndication::FeedPtr feed = Syndication::parserCollection()->parse(document, QStringLiteral("Atom"));
-            processFeed(feed, url);
+            processFeed(feed, url, markEntriesRead);
         }
         delete reply;
     });
@@ -60,9 +61,18 @@ void Fetcher::fetchAll()
     }
 }
 
-void Fetcher::processFeed(Syndication::FeedPtr feed, const QString &url)
+void Fetcher::setFetchCount(int count)
+{
+    m_fetchCount = count;
+    Q_EMIT refreshingChanged(refreshing());
+}
+
+void Fetcher::processFeed(Syndication::FeedPtr feed, const QString &url, const bool markEntriesRead)
 {
     if (feed.isNull()) {
+        Syndication::ErrorCode errorCode = Syndication::parserCollection()->lastError();
+        QString errorString = syndicationErrorToString(errorCode);
+        Q_EMIT error(url, errorCode, errorString);
         return;
     }
 
@@ -94,13 +104,13 @@ void Fetcher::processFeed(Syndication::FeedPtr feed, const QString &url)
     Q_EMIT feedDetailsUpdated(url, feed->title(), image, feed->link(), feed->description(), current);
 
     for (const auto &entry : feed->items()) {
-        processEntry(entry, url);
+        processEntry(entry, url, markEntriesRead);
     }
 
     Q_EMIT feedUpdated(url);
 }
 
-void Fetcher::processEntry(Syndication::ItemPtr entry, const QString &url)
+void Fetcher::processEntry(Syndication::ItemPtr entry, const QString &url, const bool markEntriesRead)
 {
     qDebug() << "Processing" << entry->title();
     QSqlQuery query;
@@ -113,13 +123,14 @@ void Fetcher::processEntry(Syndication::ItemPtr entry, const QString &url)
         return;
     }
 
-    query.prepare(QStringLiteral("INSERT INTO Entries VALUES (:feed, :id, :title, :content, :created, :updated, :link, 0);"));
+    query.prepare(QStringLiteral("INSERT INTO Entries VALUES (:feed, :id, :title, :content, :created, :updated, :link, :read);"));
     query.bindValue(QStringLiteral(":feed"), url);
     query.bindValue(QStringLiteral(":id"), entry->id());
     query.bindValue(QStringLiteral(":title"), QTextDocumentFragment::fromHtml(entry->title()).toPlainText());
     query.bindValue(QStringLiteral(":created"), static_cast<int>(entry->datePublished()));
     query.bindValue(QStringLiteral(":updated"), static_cast<int>(entry->dateUpdated()));
     query.bindValue(QStringLiteral(":link"), entry->link());
+    query.bindValue(QStringLiteral(":read"), markEntriesRead);
 
     if (!entry->content().isEmpty()) {
         query.bindValue(QStringLiteral(":content"), entry->content());
@@ -200,7 +211,8 @@ void Fetcher::removeImage(const QString &url)
 
 QString Fetcher::filePath(const QString &url)
 {
-    return QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QStringLiteral("/") + QString::fromStdString(QCryptographicHash::hash(url.toUtf8(), QCryptographicHash::Md5).toHex().toStdString());
+    return QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QStringLiteral("/")
+        + QString::fromStdString(QCryptographicHash::hash(url.toUtf8(), QCryptographicHash::Md5).toHex().toStdString());
 }
 
 QNetworkReply *Fetcher::get(QNetworkRequest &request)
@@ -208,3 +220,15 @@ QNetworkReply *Fetcher::get(QNetworkRequest &request)
     request.setRawHeader("User-Agent", "Alligator/0.1; Syndication");
     return manager->get(request);
 }
+
+QString Fetcher::syndicationErrorToString(Syndication::ErrorCode errorCode)
+{
+    switch (errorCode) {
+    case Syndication::InvalidXml:
+        return i18n("Invalid XML");
+    case Syndication::XmlNotAccepted:
+        return i18n("No parser accepted the XML");
+    default:
+        return i18n("Error while parsing feed");
+    }
+}
